@@ -68,6 +68,17 @@ def canonicalize_force(energy_or_force_fn: Union[EnergyFn, ForceFn]) -> ForceFn:
   return force_fn
 
 
+def volume(dimension: int, box: Box) -> float:
+  if jnp.isscalar(box) or not box.ndim:
+    return box ** dimension
+  elif box.ndim == 1:
+    return jnp.prod(box)
+  elif box.ndim == 2:
+    return jnp.linalg.det(box)
+  raise ValueError(('Box must be either: a scalar, a vector, or a matrix. '
+                    f'Found {box}.'))
+
+
 def kinetic_energy(velocity: Array, mass: Array=1.0) -> float:
   """Computes the kinetic energy of a system with some velocities."""
   return 0.5 * util.high_precision_sum(mass * velocity ** 2)
@@ -79,6 +90,32 @@ def temperature(velocity: Array, mass: Array=1.0) -> float:
   return util.high_precision_sum(mass * velocity ** 2) / (N * dim)
 
 
+def pressure(energy_fn: EnergyFn, position: Array, box: Box,
+             kinetic_energy: float=0.0, **kwargs) -> float:
+  """Computes the internal pressure of a system.
+
+  Note: This function requires that `energy_fn` take a `box` keyword argument.
+  Most frequently, this is accomplished by using `periodic_general` boundary
+  conditions combined with any of the energy functions in `energy.py`. This
+  will not work with `space.periodic`.
+  """
+  dim = position.shape[1]
+
+  vol_0 = volume(dim, box)
+  box_fn = lambda vol: (vol / vol_0) ** (1 / dim) * box
+
+  def U(vol):
+    return energy_fn(position, box=box_fn(vol), **kwargs)
+
+  dUdV = grad(U)
+  KE = kinetic_energy
+  F = force(energy_fn)(position, box=box, **kwargs)
+  R = space.transform(box, position)
+  RdotF = util.high_precision_sum(R * F)
+
+  return 1 / (dim * vol_0) * (2 * KE + RdotF - dim * vol_0 * dUdV(vol_0))
+
+
 def canonicalize_mass(mass: Union[float, Array]) -> Union[float, Array]:
   if isinstance(mass, float):
     return mass
@@ -129,7 +166,8 @@ def is_integer(x: Array) -> bool:
 def pair_correlation(displacement_or_metric: Union[DisplacementFn, MetricFn],
                      radii: Array,
                      sigma: float,
-                     species: Array=None):
+                     species: Array = None,
+                     eps: float = 1e-7):
   """Computes the pair correlation function at a mesh of distances.
 
   The pair correlation function measures the number of particles at a given
@@ -146,6 +184,8 @@ def pair_correlation(displacement_or_metric: Union[DisplacementFn, MetricFn],
     species: An optional array specifying the species of each particle. If
       species is None then we compute a single g(r) for all particles,
       otherwise we compute one g(r) for each species.
+    eps: A small additive constant used to ensure stability if the radius is
+      zero.
 
   Returns:
     A function `g_fn` that computes the pair correlation function for a
@@ -153,8 +193,11 @@ def pair_correlation(displacement_or_metric: Union[DisplacementFn, MetricFn],
   """
   d = space.canonicalize_displacement_or_metric(displacement_or_metric)
   d = space.map_product(d)
+
+  inv_rad = 1 / (radii + eps)
+
   def pairwise(dr, dim):
-    return jnp.exp(-f32(0.5) * (dr - radii)**2 / sigma**2) / radii**(dim - 1)
+    return jnp.exp(-f32(0.5) * (dr - radii)**2 / sigma**2) * inv_rad**(dim - 1)
   pairwise = vmap(vmap(pairwise, (0, None)), (0, None))
 
   if species is None:
@@ -184,8 +227,9 @@ def pair_correlation_neighbor_list(
     box_size: Box,
     radii: Array,
     sigma: float,
-    species: Array=None,
-    dr_threshold: float=0.5):
+    species: Array = None,
+    dr_threshold: float = 0.5,
+    eps: float = 1e-7):
   """Computes the pair correlation function at a mesh of distances.
 
   The pair correlation function measures the number of particles at a given
@@ -206,6 +250,8 @@ def pair_correlation_neighbor_list(
       species is None then we compute a single g(r) for all particles,
       otherwise we compute one g(r) for each species.
     dr_threshold: A float specifying the halo size of the neighobr list.
+    eps: A small additive constant used to ensure stability if the radius is
+      zero.
 
   Returns:
     A pair of functions: `neighbor_fn` that constructs a neighbor list (see
@@ -215,8 +261,9 @@ def pair_correlation_neighbor_list(
   """
   d = space.canonicalize_displacement_or_metric(displacement_or_metric)
   d = space.map_neighbor(d)
+  inv_rad = 1 / (radii + eps)
   def pairwise(dr, dim):
-    return jnp.exp(-f32(0.5) * (dr - radii)**2 / sigma**2) / radii**(dim - 1)
+    return jnp.exp(-f32(0.5) * (dr - radii)**2 / sigma**2) * inv_rad**(dim - 1)
   pairwise = vmap(vmap(pairwise, (0, None)), (0, None))
 
   neighbor_fn = partition.neighbor_list(displacement_or_metric,
